@@ -213,6 +213,26 @@ class TpuAsyncClient:
     ) -> pagers.ListNodesAsyncPager:
         r"""Lists nodes.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_list_nodes():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.ListNodesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_nodes(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.ListNodesRequest, dict]):
                 The request object. Request for
@@ -291,6 +311,25 @@ class TpuAsyncClient:
     ) -> cloud_tpu.Node:
         r"""Gets the details of a node.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_get_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GetNodeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_node(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GetNodeRequest, dict]):
                 The request object. Request for
@@ -360,6 +399,34 @@ class TpuAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a node.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_create_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                node = tpu_v2alpha1.Node()
+                node.accelerator_type = "accelerator_type_value"
+                node.runtime_version = "runtime_version_value"
+
+                request = tpu_v2alpha1.CreateNodeRequest(
+                    parent="parent_value",
+                    node=node,
+                )
+
+                # Make the request
+                operation = client.create_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.CreateNodeRequest, dict]):
                 The request object. Request for
@@ -454,6 +521,29 @@ class TpuAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a node.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_delete_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.DeleteNodeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.DeleteNodeRequest, dict]):
                 The request object. Request for
@@ -534,6 +624,29 @@ class TpuAsyncClient:
         r"""Stops a node. This operation is only available with
         single TPU nodes.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_stop_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.StopNodeRequest(
+                )
+
+                # Make the request
+                operation = client.stop_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.StopNodeRequest, dict]):
                 The request object. Request for
@@ -594,6 +707,28 @@ class TpuAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Starts a node.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_start_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.StartNodeRequest(
+                )
+
+                # Make the request
+                operation = client.start_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.StartNodeRequest, dict]):
                 The request object. Request for
@@ -656,6 +791,33 @@ class TpuAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the configurations of a node.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_update_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                node = tpu_v2alpha1.Node()
+                node.accelerator_type = "accelerator_type_value"
+                node.runtime_version = "runtime_version_value"
+
+                request = tpu_v2alpha1.UpdateNodeRequest(
+                    node=node,
+                )
+
+                # Make the request
+                operation = client.update_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.UpdateNodeRequest, dict]):
                 The request object. Request for
@@ -749,6 +911,26 @@ class TpuAsyncClient:
         r"""Generates the Cloud TPU service identity for the
         project.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_generate_service_identity():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GenerateServiceIdentityRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.generate_service_identity(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GenerateServiceIdentityRequest, dict]):
                 The request object. Request for
@@ -799,6 +981,26 @@ class TpuAsyncClient:
     ) -> pagers.ListAcceleratorTypesAsyncPager:
         r"""Lists accelerator types supported by this API.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_list_accelerator_types():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.ListAcceleratorTypesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_accelerator_types(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.ListAcceleratorTypesRequest, dict]):
                 The request object. Request for
@@ -877,6 +1079,25 @@ class TpuAsyncClient:
     ) -> cloud_tpu.AcceleratorType:
         r"""Gets AcceleratorType.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_get_accelerator_type():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GetAcceleratorTypeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_accelerator_type(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GetAcceleratorTypeRequest, dict]):
                 The request object. Request for
@@ -946,6 +1167,26 @@ class TpuAsyncClient:
     ) -> pagers.ListRuntimeVersionsAsyncPager:
         r"""Lists runtime versions supported by this API.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_list_runtime_versions():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.ListRuntimeVersionsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_runtime_versions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.ListRuntimeVersionsRequest, dict]):
                 The request object. Request for
@@ -1024,6 +1265,25 @@ class TpuAsyncClient:
     ) -> cloud_tpu.RuntimeVersion:
         r"""Gets a runtime version.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_get_runtime_version():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GetRuntimeVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_runtime_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GetRuntimeVersionRequest, dict]):
                 The request object. Request for
@@ -1092,6 +1352,25 @@ class TpuAsyncClient:
     ) -> cloud_tpu.GetGuestAttributesResponse:
         r"""Retrieves the guest attributes for the node.
 
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_get_guest_attributes():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GetGuestAttributesRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_guest_attributes(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GetGuestAttributesRequest, dict]):
                 The request object. Request for
