@@ -448,6 +448,27 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> pagers.ListNodesPager:
         r"""Lists nodes.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_list_nodes():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.ListNodesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_nodes(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.ListNodesRequest, dict]):
                 The request object. Request for
@@ -526,6 +547,26 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> cloud_tpu.Node:
         r"""Gets the details of a node.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_get_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GetNodeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_node(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GetNodeRequest, dict]):
                 The request object. Request for
@@ -595,6 +636,35 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> operation.Operation:
         r"""Creates a node.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_create_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                node = tpu_v2alpha1.Node()
+                node.accelerator_type = "accelerator_type_value"
+                node.runtime_version = "runtime_version_value"
+
+                request = tpu_v2alpha1.CreateNodeRequest(
+                    parent="parent_value",
+                    node=node,
+                )
+
+                # Make the request
+                operation = client.create_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.CreateNodeRequest, dict]):
                 The request object. Request for
@@ -689,6 +759,30 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> operation.Operation:
         r"""Deletes a node.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_delete_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.DeleteNodeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.DeleteNodeRequest, dict]):
                 The request object. Request for
@@ -769,6 +863,30 @@ class TpuClient(metaclass=TpuClientMeta):
         r"""Stops a node. This operation is only available with
         single TPU nodes.
 
+
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_stop_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.StopNodeRequest(
+                )
+
+                # Make the request
+                operation = client.stop_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.StopNodeRequest, dict]):
                 The request object. Request for
@@ -830,6 +948,29 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> operation.Operation:
         r"""Starts a node.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_start_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.StartNodeRequest(
+                )
+
+                # Make the request
+                operation = client.start_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.StartNodeRequest, dict]):
                 The request object. Request for
@@ -893,6 +1034,34 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> operation.Operation:
         r"""Updates the configurations of a node.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_update_node():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                node = tpu_v2alpha1.Node()
+                node.accelerator_type = "accelerator_type_value"
+                node.runtime_version = "runtime_version_value"
+
+                request = tpu_v2alpha1.UpdateNodeRequest(
+                    node=node,
+                )
+
+                # Make the request
+                operation = client.update_node(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.UpdateNodeRequest, dict]):
                 The request object. Request for
@@ -986,6 +1155,27 @@ class TpuClient(metaclass=TpuClientMeta):
         r"""Generates the Cloud TPU service identity for the
         project.
 
+
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_generate_service_identity():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GenerateServiceIdentityRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.generate_service_identity(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GenerateServiceIdentityRequest, dict]):
                 The request object. Request for
@@ -1039,6 +1229,27 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> pagers.ListAcceleratorTypesPager:
         r"""Lists accelerator types supported by this API.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_list_accelerator_types():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.ListAcceleratorTypesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_accelerator_types(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.ListAcceleratorTypesRequest, dict]):
                 The request object. Request for
@@ -1117,6 +1328,26 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> cloud_tpu.AcceleratorType:
         r"""Gets AcceleratorType.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_get_accelerator_type():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GetAcceleratorTypeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_accelerator_type(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GetAcceleratorTypeRequest, dict]):
                 The request object. Request for
@@ -1186,6 +1417,27 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> pagers.ListRuntimeVersionsPager:
         r"""Lists runtime versions supported by this API.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_list_runtime_versions():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.ListRuntimeVersionsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_runtime_versions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.ListRuntimeVersionsRequest, dict]):
                 The request object. Request for
@@ -1264,6 +1516,26 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> cloud_tpu.RuntimeVersion:
         r"""Gets a runtime version.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_get_runtime_version():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GetRuntimeVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_runtime_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GetRuntimeVersionRequest, dict]):
                 The request object. Request for
@@ -1332,6 +1604,26 @@ class TpuClient(metaclass=TpuClientMeta):
     ) -> cloud_tpu.GetGuestAttributesResponse:
         r"""Retrieves the guest attributes for the node.
 
+
+        .. code-block::
+
+            from google.cloud import tpu_v2alpha1
+
+            def sample_get_guest_attributes():
+                # Create a client
+                client = tpu_v2alpha1.TpuClient()
+
+                # Initialize request argument(s)
+                request = tpu_v2alpha1.GetGuestAttributesRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_guest_attributes(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.tpu_v2alpha1.types.GetGuestAttributesRequest, dict]):
                 The request object. Request for
